@@ -1,9 +1,14 @@
 var dhcp6__messages_8cc =
 [
     [ "isc::dhcp::DHCP4_HOOK_SUBNET6_SELECT_PARKING_LOT_FULL", "d5/d8c/namespaceisc_1_1dhcp.html#a82cc9e3fdb2048c2d6ea1121d9ddb920", null ],
-    [ "isc::dhcp::DHCP6_ACTIVATE_INTERFACE", "d5/d8c/namespaceisc_1_1dhcp.html#af52ff66da71e28a6486ff8c248e0cd80", null ],
     [ "isc::dhcp::DHCP6_ADD_GLOBAL_STATUS_CODE", "d5/d8c/namespaceisc_1_1dhcp.html#a5986f4801cd782fee3f8adbc96fc13fb", null ],
     [ "isc::dhcp::DHCP6_ADD_STATUS_CODE_FOR_IA", "d5/d8c/namespaceisc_1_1dhcp.html#af3dff4377db16fd2307c32dc16906184", null ],
+    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_EVAL_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a42cab2ca4b110c93a4fff74fe9e95a3f", null ],
+    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_EVAL_RESULT", "d5/d8c/namespaceisc_1_1dhcp.html#a09f71d5c78d7b766176c909258dfeef4", null ],
+    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_NO_TEST", "d5/d8c/namespaceisc_1_1dhcp.html#a093058e3b6bc25ad853c84b39fe16189", null ],
+    [ "isc::dhcp::DHCP6_ADDITIONAL_CLASS_UNDEFINED", "d5/d8c/namespaceisc_1_1dhcp.html#a2579488e0b97a362f4a8c2777192633c", null ],
+    [ "isc::dhcp::DHCP6_ADDR_REG_INFORM_CLIENT_CHANGE", "d5/d8c/namespaceisc_1_1dhcp.html#a1c195c116ecc33ade0d4e024e7113707", null ],
+    [ "isc::dhcp::DHCP6_ADDR_REG_INFORM_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a779c1ee8e64300b6dc2a90a516cb8056", null ],
     [ "isc::dhcp::DHCP6_ALREADY_RUNNING", "d5/d8c/namespaceisc_1_1dhcp.html#a7f407abed4e7f7873deb4a5703d1dcdd", null ],
     [ "isc::dhcp::DHCP6_BUFFER_RECEIVED", "d5/d8c/namespaceisc_1_1dhcp.html#a04936fb907d7f40ee94299ce71fd4658", null ],
     [ "isc::dhcp::DHCP6_BUFFER_UNPACK", "d5/d8c/namespaceisc_1_1dhcp.html#a2f1fe4c90d0155c1f22b638995c208f7", null ],
@@ -13,8 +18,6 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_CB_PERIODIC_FETCH_UPDATES_RETRIES_EXHAUSTED", "d5/d8c/namespaceisc_1_1dhcp.html#a76e9a01f0ce4d225c4d5369f7c825b26", null ],
     [ "isc::dhcp::DHCP6_CLASS_ASSIGNED", "d5/d8c/namespaceisc_1_1dhcp.html#abff43ad65ae0c3a367edd98414cee76c", null ],
     [ "isc::dhcp::DHCP6_CLASS_UNCONFIGURED", "d5/d8c/namespaceisc_1_1dhcp.html#ab9cae6eadd2144e30f1d2499593b9d31", null ],
-    [ "isc::dhcp::DHCP6_CLASS_UNDEFINED", "d5/d8c/namespaceisc_1_1dhcp.html#a1e05d292a9a9bc18d43350bdef59e5a8", null ],
-    [ "isc::dhcp::DHCP6_CLASS_UNTESTABLE", "d5/d8c/namespaceisc_1_1dhcp.html#ae6a40c6ffc20f7bf2401193c56e41555", null ],
     [ "isc::dhcp::DHCP6_CLASSES_ASSIGNED", "d5/d8c/namespaceisc_1_1dhcp.html#a5c3c9d208860dc98749486fd4b92e6f9", null ],
     [ "isc::dhcp::DHCP6_CLASSES_ASSIGNED_AFTER_SUBNET_SELECTION", "d5/d8c/namespaceisc_1_1dhcp.html#adacfcd01d476bc39d451026d2d6797da", null ],
     [ "isc::dhcp::DHCP6_CONFIG_COMPLETE", "d5/d8c/namespaceisc_1_1dhcp.html#a4c8e06c34af0c9b310831b53a6fd0dc6", null ],
@@ -25,8 +28,7 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_CONFIG_SYNTAX_WARNING", "d5/d8c/namespaceisc_1_1dhcp.html#a28896879e5362d2355e9c79ad93e1aa7", null ],
     [ "isc::dhcp::DHCP6_CONFIG_UNRECOVERABLE_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#aa1ba860b8cfbb5886dce6ac94e780e63", null ],
     [ "isc::dhcp::DHCP6_CONFIG_UNSUPPORTED_OBJECT", "d5/d8c/namespaceisc_1_1dhcp.html#a9cfe606adaef71577a2d611f48d7fc9e", null ],
-    [ "isc::dhcp::DHCP6_CONFIG_UPDATE", "d5/d8c/namespaceisc_1_1dhcp.html#a6c16c0c9b7fb77e69a94790356d6e933", null ],
-    [ "isc::dhcp::DHCP6_DB_BACKEND_STARTED", "d5/d8c/namespaceisc_1_1dhcp.html#ae840d5c2e3a4a6ec0d537b2fe6543fc9", null ],
+    [ "isc::dhcp::DHCP6_DATA_DIRECTORY_DEPRECATED", "d5/d8c/namespaceisc_1_1dhcp.html#a304680d2bb59f5eea0b9cdc4738466fc", null ],
     [ "isc::dhcp::DHCP6_DB_RECONNECT_DISABLED", "d5/d8c/namespaceisc_1_1dhcp.html#ab33550c696ffab5c71bd858d1d38a212", null ],
     [ "isc::dhcp::DHCP6_DB_RECONNECT_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#af12214342ce3153b4a34aba9c2054dd6", null ],
     [ "isc::dhcp::DHCP6_DB_RECONNECT_LOST_CONNECTION", "d5/d8c/namespaceisc_1_1dhcp.html#ad29ec2308b248e5b24f23c0e498adccf", null ],
@@ -40,8 +42,6 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_DDNS_REMOVE_OLD_LEASE_FQDN", "d5/d8c/namespaceisc_1_1dhcp.html#a5272b73a5ae4e7ef84e682e4dff0af2d", null ],
     [ "isc::dhcp::DHCP6_DDNS_REQUEST_SEND_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a001c45f5b420a44d378ce4d909042924", null ],
     [ "isc::dhcp::DHCP6_DDNS_RESPONSE_FQDN_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a5ad1ece40d4adf47b453aae1ac5b3fde", null ],
-    [ "isc::dhcp::DHCP6_DDNS_SEND_FQDN", "d5/d8c/namespaceisc_1_1dhcp.html#a741c1e031f3dd7648b347933fbaa4a41", null ],
-    [ "isc::dhcp::DHCP6_DEACTIVATE_INTERFACE", "d5/d8c/namespaceisc_1_1dhcp.html#a35d889dd1ebb72a001cc1a231be1be86", null ],
     [ "isc::dhcp::DHCP6_DECLINE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#aa789585dfbb10c894b17310935ad7799", null ],
     [ "isc::dhcp::DHCP6_DECLINE_FAIL_DUID_MISMATCH", "d5/d8c/namespaceisc_1_1dhcp.html#acc9237c459dcc85d23f5fd64bfad1b58", null ],
     [ "isc::dhcp::DHCP6_DECLINE_FAIL_IAID_MISMATCH", "d5/d8c/namespaceisc_1_1dhcp.html#a7962ba9bbc36c5309ba5ba3a80632ebe", null ],
@@ -59,7 +59,8 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_DYNAMIC_RECONFIGURATION_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a973b5fa2c89b7ff6bef5b93c2a3140f1", null ],
     [ "isc::dhcp::DHCP6_DYNAMIC_RECONFIGURATION_SUCCESS", "d5/d8c/namespaceisc_1_1dhcp.html#a62d40aa538e0e188d0dc21a7cad12251", null ],
     [ "isc::dhcp::DHCP6_FLEX_ID", "d5/d8c/namespaceisc_1_1dhcp.html#a11a176cae92cbbdf0ba2f103e84540d8", null ],
-    [ "isc::dhcp::DHCP6_HANDLE_SIGNAL_EXCEPTION", "d5/d8c/namespaceisc_1_1dhcp.html#a1d8bfc5b665190b48dc4ae11ea7f8bab", null ],
+    [ "isc::dhcp::DHCP6_HOOK_ADDR6_REGISTER_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#ae3df3d2d2a43b80d7cf9d9472bfe8208", null ],
+    [ "isc::dhcp::DHCP6_HOOK_ADDR6_REGISTER_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#a9c8a9685780f2c503c42483d2ea263ec", null ],
     [ "isc::dhcp::DHCP6_HOOK_BUFFER_RCVD_DROP", "d5/d8c/namespaceisc_1_1dhcp.html#aef0babbda3e8a607c1e2cd631791181f", null ],
     [ "isc::dhcp::DHCP6_HOOK_BUFFER_RCVD_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#aa77f57a64c27cb4e187857179032a646", null ],
     [ "isc::dhcp::DHCP6_HOOK_BUFFER_SEND_SKIP", "d5/d8c/namespaceisc_1_1dhcp.html#af5a746ffc3464f256fb5de89f4b14165", null ],
@@ -89,10 +90,8 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_LEASE_REUSE", "d5/d8c/namespaceisc_1_1dhcp.html#a98d4f37b07ff85387cba0c4873a75e9b", null ],
     [ "isc::dhcp::DHCP6_MULTI_THREADING_INFO", "d5/d8c/namespaceisc_1_1dhcp.html#aed3790e801d9e29a6ae69c920fd714d5", null ],
     [ "isc::dhcp::DHCP6_NO_INTERFACES", "d5/d8c/namespaceisc_1_1dhcp.html#a95e054a17a2b948323be4e8f44c6b06f", null ],
-    [ "isc::dhcp::DHCP6_NO_SOCKETS_OPEN", "d5/d8c/namespaceisc_1_1dhcp.html#aab8b71029b1f656b6f1dd80eb4210003", null ],
     [ "isc::dhcp::DHCP6_NOT_RUNNING", "d5/d8c/namespaceisc_1_1dhcp.html#a7b9428be18d8b0725074fbc96242a556", null ],
     [ "isc::dhcp::DHCP6_OPEN_SOCKET", "d5/d8c/namespaceisc_1_1dhcp.html#a445a842c31fa46d8ab673e6e791afc67", null ],
-    [ "isc::dhcp::DHCP6_OPEN_SOCKET_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#ac2f3143b9f23d5b1f9fc54a9ba5614dd", null ],
     [ "isc::dhcp::DHCP6_OPEN_SOCKETS_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a55ba24022df92feab6508beb7442fae6", null ],
     [ "isc::dhcp::DHCP6_OPEN_SOCKETS_NO_RECONNECT_CTL", "d5/d8c/namespaceisc_1_1dhcp.html#a126eca4f33d4110114094b99df593d60", null ],
     [ "isc::dhcp::DHCP6_PACK_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a44f580c657aed0095a6b72cfb4c2491c", null ],
@@ -136,6 +135,9 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_QUERY_LABEL", "d5/d8c/namespaceisc_1_1dhcp.html#a2957a3457aec1dff036dd953d267fdab", null ],
     [ "isc::dhcp::DHCP6_RAPID_COMMIT", "d5/d8c/namespaceisc_1_1dhcp.html#ad0f7626624a723fe37529e0f41df5179", null ],
     [ "isc::dhcp::DHCP6_RECLAIM_EXPIRED_LEASES_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a4c8876e76807b529b8b8a3c24d7b091d", null ],
+    [ "isc::dhcp::DHCP6_RECLAIM_EXPIRED_LEASES_SKIPPED", "d5/d8c/namespaceisc_1_1dhcp.html#a3bbeca1b4ec98724ae0c8d6a5a265f01", null ],
+    [ "isc::dhcp::DHCP6_REGISTERED_LEASE_ADD_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a120db9f6a2a3bd5bdaa3842d6f6fcdb5", null ],
+    [ "isc::dhcp::DHCP6_REGISTERED_LEASE_UPDATE_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a313d1a8ddfe17d65b66769b4dfa11743", null ],
     [ "isc::dhcp::DHCP6_RELEASE_NA", "d5/d8c/namespaceisc_1_1dhcp.html#a5b8e50af45d50bb221accd49eac070fa", null ],
     [ "isc::dhcp::DHCP6_RELEASE_NA_DELETED", "d5/d8c/namespaceisc_1_1dhcp.html#a0626ba8edb39fdcfb69290c6c4f9b8b0", null ],
     [ "isc::dhcp::DHCP6_RELEASE_NA_EXPIRED", "d5/d8c/namespaceisc_1_1dhcp.html#a91563e13dd131fddfd23d32eded6793f", null ],
@@ -151,14 +153,14 @@ var dhcp6__messages_8cc =
     [ "isc::dhcp::DHCP6_REQUIRED_OPTIONS_CHECK_FAIL", "d5/d8c/namespaceisc_1_1dhcp.html#a5f1390211542afeba52c19fae013ad15", null ],
     [ "isc::dhcp::DHCP6_RESERVATIONS_LOOKUP_FIRST_ENABLED", "d5/d8c/namespaceisc_1_1dhcp.html#a74ae56eb998780aa80e5f91379f5e704", null ],
     [ "isc::dhcp::DHCP6_RESPONSE_DATA", "d5/d8c/namespaceisc_1_1dhcp.html#a9274654c848e4cec10ff51ac2e5cea51", null ],
+    [ "isc::dhcp::DHCP6_ROOT_USER_SECURITY_WARNING", "d5/d8c/namespaceisc_1_1dhcp.html#a90c3798acefc37ff78df6597bc1c33db", null ],
+    [ "isc::dhcp::DHCP6_SECURITY_CHECKS_DISABLED", "d5/d8c/namespaceisc_1_1dhcp.html#a7f22485f9bed24a0949d110679c9857c", null ],
     [ "isc::dhcp::DHCP6_SERVER_FAILED", "d5/d8c/namespaceisc_1_1dhcp.html#a4d5fde11e41589c1a3b57214b4e5a19d", null ],
     [ "isc::dhcp::DHCP6_SHUTDOWN", "d5/d8c/namespaceisc_1_1dhcp.html#a644cfed2f9bf7d22ad81193c92b7fa76", null ],
     [ "isc::dhcp::DHCP6_SHUTDOWN_REQUEST", "d5/d8c/namespaceisc_1_1dhcp.html#aa7638f485c9fa83949c9e6bd89b949e7", null ],
-    [ "isc::dhcp::DHCP6_SOCKET_UNICAST", "d5/d8c/namespaceisc_1_1dhcp.html#a1fd2f15de12a33fe31da91812967dd73", null ],
     [ "isc::dhcp::DHCP6_SRV_CONSTRUCT_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a666f6cd29898db9d764798148cce12c0", null ],
     [ "isc::dhcp::DHCP6_SRV_D2STOP_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#a307d00cdb40f2348754d2f95fb3bf2f5", null ],
     [ "isc::dhcp::DHCP6_SRV_UNLOAD_LIBRARIES_ERROR", "d5/d8c/namespaceisc_1_1dhcp.html#acebe5398bb6fb9d0a097df0f2b580734", null ],
-    [ "isc::dhcp::DHCP6_STANDALONE", "d5/d8c/namespaceisc_1_1dhcp.html#a009df7265137e50c57111f700055a940", null ],
     [ "isc::dhcp::DHCP6_START_INFO", "d5/d8c/namespaceisc_1_1dhcp.html#a6e55469155928664d15d56fca7e7ce16", null ],
     [ "isc::dhcp::DHCP6_STARTED", "d5/d8c/namespaceisc_1_1dhcp.html#a67a4a86ff36b69005c791564de3a5031", null ],
     [ "isc::dhcp::DHCP6_STARTING", "d5/d8c/namespaceisc_1_1dhcp.html#a6b3e033ae3c9f86e9b25b59c1cbca447", null ],
